pub struct Subscription {
pub view: String,
pub key: Option<String>,
pub partition: Option<String>,
pub filters: Option<HashMap<String, String>>,
pub take: Option<u32>,
pub skip: Option<u32>,
pub with_snapshot: Option<bool>,
pub after: Option<String>,
pub snapshot_limit: Option<usize>,
}Fields
view: Stringkey: Option<String>partition: Option<String>filters: Option<HashMap<String, String>>take: Option<u32>skip: Option<u32>with_snapshot: Option<bool>Whether to include initial snapshot (defaults to true for backward compatibility)
after: Option<String>Cursor for resuming from a specific point (_seq value)
snapshot_limit: Option<usize>Maximum number of entities to include in snapshot (pagination hint)
Implementations
Sourceimpl Subscription
impl Subscription
pub fn new(view: impl Into<String>) -> Self
pub fn with_key(self, key: impl Into<String>) -> Self
pub fn with_filters(self, filters: HashMap<String, String>) -> Self
pub fn with_take(self, take: u32) -> Self
pub fn with_skip(self, skip: u32) -> Self
Sourcepub fn with_snapshot(self, with_snapshot: bool) -> Self
pub fn with_snapshot(self, with_snapshot: bool) -> Self
Set whether to include the initial snapshot (defaults to true)
Sourcepub fn after(self, cursor: impl Into<String>) -> Self
pub fn after(self, cursor: impl Into<String>) -> Self
Set the cursor to resume from (for reconnecting and getting only newer data)
Sourcepub fn with_snapshot_limit(self, limit: usize) -> Self
pub fn with_snapshot_limit(self, limit: usize) -> Self
Set the maximum number of entities to include in the snapshot
pub fn sub_key(&self) -> String